Given a sequence of distance matrices, expected to correspond to sequential increasing values of time, calculate the average distance between any pairs of nodes shortest-path (or geodesic) distance
get_mean_distance_matrix(DM_list)getMeanDistanceMatrix(DM_list)
mean-distance matrix
list of distance matrices
getMeanDistanceMatrix(): Old deprecated function
De Domenico, M. (2017). Diffusion Geometry Unravels the Emergence of Functional Clusters in Collective Phenomena. Physical Review Letters. tools:::Rd_expr_doi("10.1103/PhysRevLett.118.168301")
Bertagnolli, G., & De Domenico, M. (2020). Diffusion Geometry of Multiplex and Interdependent Systems. arxiv preprint arxiv:2006.13032
get_diffusion_probability_matrix, get_distance_matrix